<?php

namespace Drupal\mbp\Layout;

use Drupal\Component\Utility\Html;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Layout\LayoutDefault;

/**
 * Accordion Section Layout Class.
 */
class BootstrapAccordionSection extends LayoutDefault {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      'heading' => 'h2',
      'section_title' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $configuration = $this->getConfiguration();

    $form = parent::buildConfigurationForm($form, $form_state);

    $form['section_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Section Title'),
      '#default_value' => $this->configuration['section_title'],
      '#required' => TRUE,
      '#weight' => -50,
    ];

    $form['heading'] = [
      '#type' => 'select',
      '#options' => [
        'h2' => $this->t('Heading 2'),
        'h3' => $this->t('Heading 3'),
        'h4' => $this->t('Heading 4'),
        'h5' => $this->t('Heading 5'),
        'h6' => $this->t('Heading 6'),
      ],
      '#title' => $this->t('Heading Size'),
      '#default_value' => $this->configuration['heading'],
      '#required' => TRUE,
      '#weight' => -49,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['section_title'] = $form_state->getValue('section_title');
    $this->configuration['heading'] = $form_state->getValue('heading');
  }

  /**
   * {@inheritdoc}
   */
  public function build(array $regions) {
    $build = parent::build($regions);

    $build['#settings'] = [
      'id' => $regions['content']['#attributes']['id'] ?? HTML::getUniqueId('accordion-item'),
      'heading' => $this->configuration['heading'],
      'section_title' => $this->configuration['section_title'],
    ];

    return $build;
  }

}
